@@ -126,7 +126,7 @@ def cart2sphere(x, y, z):
        azimuth angle
     '''
     r = np.sqrt(x * x + y * y + z * z)
-    theta = np.arccos(z / r)
+    theta = np.arccos(np.divide(z, r, where=r > 0))
     theta = np.where(r > 0, theta, 0.)
     phi = np.arctan2(y, x)
     r, theta, phi = np.broadcast_arrays(r, theta, phi)
@@ -570,9 +570,9 @@ def euler_matrix(ai, aj, ak, axes='sxyz'):
     True
     >>> ai, aj, ak = (4.0*math.pi) * (numpy.random.random(3) - 0.5)
     >>> for axes in _AXES2TUPLE.keys():
-    ...    R = euler_matrix(ai, aj, ak, axes)
+    ...    _ = euler_matrix(ai, aj, ak, axes)
     >>> for axes in _TUPLE2AXES.keys():
-    ...    R = euler_matrix(ai, aj, ak, axes)
+    ...    _ = euler_matrix(ai, aj, ak, axes)
 
     """
     try:
