@@ -14,9 +14,9 @@ def test_denoise():
     # Test on 4D image:
     data = nib.load(fdata).get_data()
     sigma1 = estimate_sigma(data)
-    denoised = nlmeans(data, sigma=sigma1)
+    nlmeans(data, sigma=sigma1)
 
     # Test on 3D image:
     data = data[..., 0]
     sigma2 = estimate_sigma(data)
-    denoised = nlmeans(data, sigma=sigma2)
+    nlmeans(data, sigma=sigma2)
