@@ -280,7 +280,6 @@ def test_color_fa():
     dm = dti.TensorModel(gtab, 'LS')
     dmfit = dm.fit(data)
     fa = fractional_anisotropy(dmfit.evals)
-    cfa = color_fa(fa, dmfit.evecs)
 
     fa = np.ones((3, 3, 3))
     # evecs should be of shape (fa, 3, 3)
@@ -470,7 +469,7 @@ def test_all_constant():
     bvecs, bvals = read_bvec_file(get_data('55dir_grad.bvec'))
     gtab = grad.gradient_table_from_bvals_bvecs(bvals, bvecs.T)
     fit_methods = ['LS', 'OLS', 'NNLS', 'RESTORE']
-    for fit_method in fit_methods:
+    for _ in fit_methods:
         dm = dti.TensorModel(gtab)
         assert_almost_equal(dm.fit(100 * np.ones(bvals.shape[0])).fa, 0)
         # Doesn't matter if the signal is smaller than 1:
@@ -481,7 +480,7 @@ def test_all_zeros():
     bvecs, bvals = read_bvec_file(get_data('55dir_grad.bvec'))
     gtab = grad.gradient_table_from_bvals_bvecs(bvals, bvecs.T)
     fit_methods = ['LS', 'OLS', 'NNLS', 'RESTORE']
-    for fit_method in fit_methods:
+    for _ in fit_methods:
         dm = dti.TensorModel(gtab)
         assert_array_almost_equal(dm.fit(np.zeros(bvals.shape[0])).evals, 0)
 
@@ -506,18 +505,22 @@ def test_mask():
     dm = dti.TensorModel(gtab, 'LS', return_S0_hat=True)
     mask = np.zeros(data.shape[:-1], dtype=bool)
     mask[0, 0, 0] = True
-    dtifit = dm.fit(data)
-    dtifit_w_mask = dm.fit(data, mask=mask)
-    # Without a mask it has some value
-    assert_(not np.isnan(dtifit.fa[0, 0, 0]))
-    # Where mask is False, evals, evecs and fa should all be 0
-    assert_array_equal(dtifit_w_mask.evals[~mask], 0)
-    assert_array_equal(dtifit_w_mask.evecs[~mask], 0)
-    assert_array_equal(dtifit_w_mask.fa[~mask], 0)
-    assert_array_equal(dtifit_w_mask.S0_hat[~mask], 0)
-    # Except for the one voxel that was selected by the mask:
-    assert_almost_equal(dtifit_w_mask.fa[0, 0, 0], dtifit.fa[0, 0, 0])
-    assert_almost_equal(dtifit_w_mask.S0_hat[0, 0, 0], dtifit.S0_hat[0, 0, 0])
+    for mask_more in [True, False]:
+        if mask_more:
+            mask[0, 0, 1] = True
+        dtifit = dm.fit(data)
+        dtifit_w_mask = dm.fit(data, mask=mask)
+        # Without a mask it has some value
+        assert_(not np.isnan(dtifit.fa[0, 0, 0]))
+        # Where mask is False, evals, evecs and fa should all be 0
+        assert_array_equal(dtifit_w_mask.evals[~mask], 0)
+        assert_array_equal(dtifit_w_mask.evecs[~mask], 0)
+        assert_array_equal(dtifit_w_mask.fa[~mask], 0)
+        assert_array_equal(dtifit_w_mask.S0_hat[~mask], 0)
+        # Except for the one voxel that was selected by the mask:
+        assert_almost_equal(dtifit_w_mask.fa[0, 0, 0], dtifit.fa[0, 0, 0])
+        assert_almost_equal(dtifit_w_mask.S0_hat[0, 0, 0],
+                            dtifit.S0_hat[0, 0, 0])
 
 
 def test_nnls_jacobian_fucn():
@@ -642,7 +645,7 @@ def test_restore():
             # RESTORE estimates should be robust to dropping
             this_y = Y.copy()
             this_y[:, drop_this] = 1.0
-            for sigma in [67.0, np.ones(this_y.shape[-1]) * 67.0]:
+            for _ in [67.0, np.ones(this_y.shape[-1]) * 67.0]:
                 tensor_model = dti.TensorModel(gtab, fit_method='restore',
                                                jac=jac,
                                                sigma=67.0)
@@ -791,7 +794,7 @@ def test_decompose_tensor_nan():
                                          from_lower_triangular(D_alter))
     assert_array_almost_equal(lfine, np.array([1.7e-3, 0.3e-3, 0.2e-3]))
     assert_array_almost_equal(vfine, vref)
-    
+
     lref, vref = decompose_tensor(from_lower_triangular(D_alter))
     lalter, valter = _decompose_tensor_nan(from_lower_triangular(D_nan),
                                            from_lower_triangular(D_alter))
