@@ -152,11 +152,11 @@ def test_downsample():
     Td = [tm.downsample(s[0], pts) for s in streams]
     T = [s[0] for s in streams]
 
-    from dipy.viz import fvtk
-    r = fvtk.ren()
-    fvtk.add(r, fvtk.line(T, fvtk.red))
-    fvtk.add(r, fvtk.line(Td, fvtk.green))
-    fvtk.show(r)
+    from dipy.viz import window, actor
+    ren = window.Renderer()
+    ren.add(actor.line(T, window.red))
+    ren.add(actor.line(Td, window.green))
+    window.show(ren)
     """
 
 
@@ -172,7 +172,7 @@ def test_splines():
     z += np.random.normal(scale=0.1, size=z.shape)
     xyz = np.vstack((x, y, z)).T
     # get the B-splines smoothed result
-    xyzn = tm.spline(xyz, 3, 2, -1)
+    tm.spline(xyz, 3, 2, -1)
 
 
 def test_segment_intersection():
