@@ -53,6 +53,7 @@ from warnings import warn
 
 from nibabel.affines import apply_affine
 from scipy.spatial.distance import cdist
+from numpy import ravel_multi_index
 
 from dipy.core.geometry import dist_to_corner
 
@@ -72,30 +73,6 @@ from dipy.io.bvectxt import orientation_from_string
 import nibabel as nib
 
 
-def _rmi(index, dims):
-    """An alternate implementation of numpy.ravel_multi_index for older
-    versions of numpy.
-
-    Assumes array layout is C contiguous
-    """
-    # Upcast to integer type capable of holding largest array index
-    index = np.asarray(index, dtype=np.intp)
-    dims = np.asarray(dims)
-    if index.ndim > 2:
-        raise ValueError("Index should be 1 or 2-D")
-    elif index.ndim == 2:
-        index = index.T
-    if (index >= dims).any():
-        raise ValueError("Index exceeds dimensions")
-    strides = np.r_[dims[:0:-1].cumprod()[::-1], 1]
-    return (strides * index).sum(-1)
-
-try:
-    from numpy import ravel_multi_index
-except ImportError:
-    ravel_multi_index = _rmi
-
-
 def density_map(streamlines, vol_dims, voxel_size=None, affine=None):
     """Counts the number of unique streamlines that pass through each voxel.
 
@@ -334,7 +311,7 @@ def subsegment(streamlines, max_segment_length):
             elif ns > 1:
                 small_d = diff[ii]/ns
                 point = sl[ii]
-                for jj in xrange(ns):
+                for _ in xrange(ns):
                     point = point + small_d
                     output_sl[count] = point
                     count += 1
@@ -384,7 +361,6 @@ def seeds_from_mask(mask, density=[1, 1, 1], voxel_size=None, affine=None):
     >>> mask[0,0,0] = 1
     >>> seeds_from_mask(mask, [1,1,1], [1,1,1])
     array([[ 0.5,  0.5,  0.5]])
-
     >>> seeds_from_mask(mask, [1,2,3], [1,1,1])
     array([[ 0.5       ,  0.25      ,  0.16666667],
            [ 0.5       ,  0.75      ,  0.16666667],
@@ -398,7 +374,6 @@ def seeds_from_mask(mask, density=[1, 1, 1], voxel_size=None, affine=None):
            [ 0.55 ,  0.55 ,  1.875],
            [ 0.55 ,  1.65 ,  5.625],
            [ 0.55 ,  1.65 ,  6.875]])
-
     """
     mask = np.array(mask, dtype=bool, copy=False, ndmin=3)
     if mask.ndim != 3:
@@ -478,11 +453,9 @@ def random_seeds_from_mask(mask, seeds_count=1, seed_count_per_voxel=True,
     --------
     >>> mask = np.zeros((3,3,3), 'bool')
     >>> mask[0,0,0] = 1
-
     >>> np.random.seed(1)
     >>> random_seeds_from_mask(mask, seeds_count=1, seed_count_per_voxel=True)
     array([[-0.082978  ,  0.22032449, -0.49988563]])
-
     >>> random_seeds_from_mask(mask, seeds_count=6, seed_count_per_voxel=True)
     array([[-0.19766743, -0.35324411, -0.40766141],
            [-0.31373979, -0.15443927, -0.10323253],
@@ -496,7 +469,6 @@ def random_seeds_from_mask(mask, seeds_count=1, seed_count_per_voxel=True,
            [ 0.37638915,  0.39460666, -0.41495579],
            [-0.46094522,  0.66983042,  2.3781425 ],
            [-0.40165317,  0.92110763,  2.45788953]])
-
     """
     mask = np.array(mask, dtype=bool, copy=False, ndmin=3)
     if mask.ndim != 3:
@@ -599,10 +571,10 @@ def target(streamlines, target_mask, affine, include=True):
 @_with_initialize
 def target_line_based(streamlines, target_mask, affine=None, include=True):
     """Filters streamlines based on whether or not they pass through a ROI,
-    using a line-based algorithm. Mostly used as a remplacement of `target`
+    using a line-based algorithm. Mostly used as a replacement of `target`
     for compressed streamlines.
 
-    This function never returns single-point streamlines, wathever the
+    This function never returns single-point streamlines, whatever the
     value of `include`.
 
     Parameters
