@@ -1,6 +1,7 @@
 import os
 import sys
 import pickle
+import numpy as np
 
 from os.path import join as pjoin
 import numpy.testing as npt
@@ -56,7 +57,7 @@ class EventCounter(object):
 
     def save(self, filename):
         with open(filename, 'wb') as f:
-            pickle.dump(self.events_counts, f, protocol=-1)
+            pickle.dump(self.events_counts, f, protocol=2)
 
     @classmethod
     def load(cls, filename):
@@ -105,6 +106,40 @@ def test_wrong_interactor_style():
     npt.assert_raises(TypeError, panel.add_to_renderer, dummy_renderer)
 
 
+@npt.dec.skipif(not have_vtk or skip_it)
+@xvfb_it
+def test_rectangle_2d():
+    window_size = (700, 700)
+    show_manager = window.ShowManager(size=window_size)
+
+    rect = ui.Rectangle2D(size=(100, 50))
+    rect.set_position((50, 80))
+    npt.assert_equal(rect.position, (50, 80))
+
+    rect.color = (1, 0.5, 0)
+    npt.assert_equal(rect.color, (1, 0.5, 0))
+
+    rect.opacity = 0.5
+    npt.assert_equal(rect.opacity, 0.5)
+
+    # Check the rectangle is drawn at right place.
+    show_manager.ren.add(rect)
+    # Uncomment this to start the visualisation
+    # show_manager.start()
+
+    colors = [rect.color]
+    arr = window.snapshot(show_manager.ren, size=window_size, offscreen=True)
+    report = window.analyze_snapshot(arr, colors=colors)
+    assert report.objects == 1
+    assert report.colors_found
+
+    # Test visibility off.
+    rect.set_visibility(False)
+    arr = window.snapshot(show_manager.ren, size=window_size, offscreen=True)
+    report = window.analyze_snapshot(arr)
+    assert report.objects == 0
+
+
 @npt.dec.skipif(not have_vtk or skip_it)
 @xvfb_it
 def test_ui_button_panel(recording=False):
@@ -225,35 +260,120 @@ def test_ui_textbox(recording=False):
 @npt.dec.skipif(not have_vtk or skip_it)
 @xvfb_it
 def test_text_block_2d():
-    # TextBlock2D
     text_block = ui.TextBlock2D()
-    text_block.message = "Hello World!"
-    npt.assert_equal("Hello World!", text_block.message)
-    text_block.font_size = 18
-    npt.assert_equal("18", str(text_block.font_size))
-    text_block.font_family = "Arial"
-    npt.assert_equal("Arial", text_block.font_family)
+
+    def _check_property(obj, attr, values):
+        for value in values:
+            setattr(obj, attr, value)
+            npt.assert_equal(getattr(obj, attr), value)
+
+    _check_property(text_block, "bold", [True, False])
+    _check_property(text_block, "italic", [True, False])
+    _check_property(text_block, "shadow", [True, False])
+    _check_property(text_block, "font_size", range(100))
+    _check_property(text_block, "message", ["", "Hello World", "Line\nBreak"])
+    _check_property(text_block, "justification", ["left", "center", "right"])
+    _check_property(text_block, "position", [(350, 350), (0.5, 0.5)])
+    _check_property(text_block, "color", [(0., 0.5, 1.)])
+    _check_property(text_block, "background_color", [(0., 0.5, 1.), None])
+    _check_property(text_block, "vertical_justification",
+                        ["top", "middle", "bottom"])
+    _check_property(text_block, "font_family", ["Arial", "Courier"])
+
     with npt.assert_raises(ValueError):
         text_block.font_family = "Verdana"
-    text_block.justification = "left"
-    text_block.justification = "right"
-    text_block.justification = "center"
-    npt.assert_equal("Centered", text_block.justification)
+
     with npt.assert_raises(ValueError):
         text_block.justification = "bottom"
-    text_block.bold = True
-    text_block.bold = False
-    npt.assert_equal(False, text_block.bold)
-    text_block.italic = True
-    text_block.italic = False
-    npt.assert_equal(False, text_block.italic)
-    text_block.shadow = True
-    text_block.shadow = False
-    npt.assert_equal(False, text_block.shadow)
-    text_block.color = (1, 0, 0)
-    npt.assert_equal((1, 0, 0), text_block.color)
-    text_block.position = (2, 3)
-    npt.assert_equal((2, 3), text_block.position)
+
+    with npt.assert_raises(ValueError):
+        text_block.vertical_justification = "left"
+
+
+@npt.dec.skipif(not have_vtk or skip_it)
+@xvfb_it
+def test_text_block_2d_justification():
+    window_size = (700, 700)
+    show_manager = window.ShowManager(size=window_size)
+
+    # To help visualize the text positions.
+    grid_size = (500, 500)
+    bottom, middle, top = 50, 300, 550
+    left, center, right = 50, 300, 550
+    line_color = (1, 0, 0)
+
+    grid_top = (center, top), (grid_size[0], 1)
+    grid_bottom = (center, bottom), (grid_size[0], 1)
+    grid_left = (left, middle), (1, grid_size[1])
+    grid_right = (right, middle), (1, grid_size[1])
+    grid_middle = (center, middle), (grid_size[0], 1)
+    grid_center = (center, middle), (1, grid_size[1])
+    grid_specs = [grid_top, grid_bottom, grid_left, grid_right,
+                  grid_middle, grid_center]
+    for spec in grid_specs:
+        line = ui.Rectangle2D(center=spec[0], size=spec[1], color=line_color)
+        show_manager.ren.add(line)
+
+    font_size = 60
+    bg_color = (1, 1, 1)
+    texts = []
+    texts += [ui.TextBlock2D("HH", position=(left, top),
+                             font_size=font_size,
+                             color=(1, 0, 0), bg_color=bg_color,
+                             justification="left",
+                             vertical_justification="top")]
+    texts += [ui.TextBlock2D("HH", position=(center, top),
+                             font_size=font_size,
+                             color=(0, 1, 0), bg_color=bg_color,
+                             justification="center",
+                             vertical_justification="top")]
+    texts += [ui.TextBlock2D("HH", position=(right, top),
+                             font_size=font_size,
+                             color=(0, 0, 1), bg_color=bg_color,
+                             justification="right",
+                             vertical_justification="top")]
+
+    texts += [ui.TextBlock2D("HH", position=(left, middle),
+                             font_size=font_size,
+                             color=(1, 1, 0), bg_color=bg_color,
+                             justification="left",
+                             vertical_justification="middle")]
+    texts += [ui.TextBlock2D("HH", position=(center, middle),
+                             font_size=font_size,
+                             color=(0, 1, 1), bg_color=bg_color,
+                             justification="center",
+                             vertical_justification="middle")]
+    texts += [ui.TextBlock2D("HH", position=(right, middle),
+                             font_size=font_size,
+                             color=(1, 0, 1), bg_color=bg_color,
+                             justification="right",
+                             vertical_justification="middle")]
+
+    texts += [ui.TextBlock2D("HH", position=(left, bottom),
+                             font_size=font_size,
+                             color=(0.5, 0, 1), bg_color=bg_color,
+                             justification="left",
+                             vertical_justification="bottom")]
+    texts += [ui.TextBlock2D("HH", position=(center, bottom),
+                             font_size=font_size,
+                             color=(1, 0.5, 0), bg_color=bg_color,
+                             justification="center",
+                             vertical_justification="bottom")]
+    texts += [ui.TextBlock2D("HH", position=(right, bottom),
+                             font_size=font_size,
+                             color=(0, 1, 0.5), bg_color=bg_color,
+                             justification="right",
+                             vertical_justification="bottom")]
+
+    show_manager.ren.add(*texts)
+
+    # Uncomment this to start the visualisation
+    # show_manager.start()
+
+    arr = window.snapshot(show_manager.ren, size=window_size, offscreen=True)
+    if vtk.vtkVersion.GetVTKVersion() == "6.0.0":
+        expected = np.load(pjoin(DATA_DIR, "test_ui_text_block.npz"))
+        npt.assert_array_almost_equal(arr, expected["arr_0"])
 
 
 @npt.dec.skipif(not have_vtk or skip_it)
@@ -310,6 +430,13 @@ def test_ui_disk_slider_2d(recording=False):
     show_manager.ren.add(disk_slider_2d_test)
 
     if recording:
+        # Record the following events
+        # 1. Left Click on the disk and hold it
+        # 2. Move to the left the disk and make 1.5 tour
+        # 3. Release the disk
+        # 4. Left Click on the disk and hold it
+        # 5. Move to the right the disk and make 1 tour
+        # 6. Release the disk
         show_manager.record_events_to_file(recording_filename)
         print(list(event_counter.events_counts.items()))
         event_counter.save(expected_events_counts_filename)
@@ -326,7 +453,7 @@ def test_ui_file_select_menu_2d(recording=False):
     filename = "test_ui_file_select_menu_2d"
     recording_filename = pjoin(DATA_DIR, filename + ".log.gz")
     expected_events_counts_filename = pjoin(DATA_DIR, filename + ".pkl")
-    with InTemporaryDirectory() as tmpdir:
+    with InTemporaryDirectory():
         for i in range(10):
             _ = open("test" + str(i) + ".txt", 'wt').write('some text')
 
