@@ -13,20 +13,24 @@ Steps are:
 
 # Stdlib imports
 import os
-from os.path import join as pjoin, abspath
+import os.path as op
 import sys
 import shutil
 from subprocess import check_call
 from glob import glob
+from time import time
 
 # Third-party imports
 
+
 # We must configure the mpl backend before making any further mpl imports
 import matplotlib
 matplotlib.use('Agg')
 import matplotlib.pyplot as plt
 from matplotlib._pylab_helpers import Gcf
 
+import dipy
+
 # -----------------------------------------------------------------------------
 # Function defintions
 # -----------------------------------------------------------------------------
@@ -36,7 +40,6 @@ from matplotlib._pylab_helpers import Gcf
 # files with a known name (derived from the script name) plus a counter
 figure_basename = None
 
-
 # We must change the show command to save instead
 def show():
     allfm = Gcf.get_all_fig_managers()
@@ -52,13 +55,14 @@ plt.show = show
 # -----------------------------------------------------------------------------
 
 # Where things are
-EG_INDEX_FNAME = abspath('examples_index.rst')
-EG_SRC_DIR = abspath('examples')
+DOC_PATH = op.abspath('..')
+EG_INDEX_FNAME = op.join(DOC_PATH, 'examples_index.rst')
+EG_SRC_DIR = op.join(DOC_PATH, 'examples')
 
 # Work in examples directory
-os.chdir('examples_built')
+#os.chdir(op.join(DOC_PATH, 'examples_built'))
 
-if not os.getcwd().endswith(pjoin('doc', 'examples_built')):
+if not os.getcwd().endswith(op.join('doc', 'examples_built')):
     raise OSError('This must be run from the doc directory')
 
 # Copy the py files; check they are in the examples list and warn if not
@@ -68,8 +72,8 @@ eg_index_contents = open(EG_INDEX_FNAME, 'rt').read()
 # also to be added in the following file (valid_examples.txt). This helps
 # with debugging the examples and the documentation only a few examples at
 # the time.
-flist_name = pjoin(os.path.dirname(os.getcwd()), 'examples',
-                   'valid_examples.txt')
+flist_name = op.join(op.dirname(os.getcwd()), 'examples',
+                     'valid_examples.txt')
 flist = open(flist_name, "r")
 validated_examples = flist.readlines()
 flist.close()
@@ -82,11 +86,11 @@ validated_examples = [line.strip() for line in validated_examples]
 validated_examples = list(filter(None, validated_examples))
 
 for example in validated_examples:
-    fullpath = pjoin(EG_SRC_DIR, example)
+    fullpath = op.join(EG_SRC_DIR, example)
     if not example.endswith(".py"):
         print("%s not a python file, skipping." % example)
         continue
-    elif not os.path.isfile(fullpath):
+    elif not op.isfile(fullpath):
         print("Cannot find file, %s, skipping." % example)
         continue
     shutil.copyfile(fullpath, example)
@@ -104,25 +108,57 @@ check_call('python ../../tools/ex2rst --project dipy --outdir . .', shell=True)
 # added the path so that scripts can import other scripts on the same directory
 sys.path.insert(0, os.getcwd())
 
-# Execute each python script in the directory.
-if not os.path.isdir('fig'):
+if not op.isdir('fig'):
     os.mkdir('fig')
 
 use_xvfb = os.environ.get('TEST_WITH_XVFB', False)
+use_memprof = os.environ.get('TEST_WITH_MEMPROF', False)
 
 if use_xvfb:
-    from xvfbwrapper import Xvfb
+    try:
+        from xvfbwrapper import Xvfb
+    except ImportError:
+        raise RuntimeError("You are trying to run a documentation build",
+                           "with 'TEST_WITH_XVFB' set to True, but ",
+                           "xvfbwrapper is not available. Please install",
+                           "xvfbwrapper and try again")
+
     display = Xvfb(width=1920, height=1080)
     display.start()
 
-for script in validated_examples:
+if use_memprof:
+    try:
+        import memory_profiler
+    except ImportError:
+        raise RuntimeError("You are trying to run a documentation build",
+                           "with 'TEST_WITH_MEMPROF' set to True, but ",
+                           "memory_profiler is not available. Please install",
+                           "memory_profiler and try again")
+
+name = ''
+
+
+def run_script():
     namespace = {}
-    figure_basename = os.path.join('fig', os.path.splitext(script)[0])
-    print(script)
+    t1 = time()
     exec(open(script).read(), namespace)
+    t2 = time()
+    print("That took %.2f seconds to run" % (t2 - t1))
     plt.close('all')
     del namespace
 
+
+# Execute each python script in the directory:
+for script in validated_examples:
+    figure_basename = op.join('fig', op.splitext(script)[0])
+    if use_memprof:
+        print("memory profiling ", script)
+        memory_profiler.profile(run_script)()
+
+    else:
+        print(script)
+        run_script()
+
 if use_xvfb:
     display.stop()
 
